<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns="http://www.w3.org/1999/xhtml"> 

<xsl:output method="xhtml:xhtml"/>


<!-- INTERFACE -->
<xsl:template name="interface">
  <xsl:param name="module"/>
  <xsl:param name="standard"/>
  <html>
    <head>
      <title> Interface <xsl:value-of select="@name"/> </title>
      <link href="../global.css" rel="stylesheet" type="text/css" />
      <link href="../reference.css" rel="stylesheet" type="text/css" />
      <link href="../example.css" rel="stylesheet" type="text/css" />
    </head>
    <body>
    
      <!-- HEADER -->
      <xsl:call-template name="header">
        <xsl:with-param name="standard"><xsl:value-of select="$standard"/></xsl:with-param>
        <xsl:with-param name="module"><xsl:value-of select="$module"/></xsl:with-param>
        <xsl:with-param name="interface"><xsl:value-of select="@name"/></xsl:with-param>
        <xsl:with-param name="property">null</xsl:with-param>
      </xsl:call-template>
      
      <!-- INTERFACE body -->
      <h2><xsl:value-of select="@name"/> (interface)</h2>

      <div>
        <span class="bold2">Type of the interface: </span>
        &#160; <a href="../_glossary.html#{@type}" class="code"><xsl:value-of select="@type"/></a>
      </div>

      <br />
      <div>
        <span class="bold2">Own properties: </span>
      </div>
      <table class="inner" border="0" cellspacing="0">
        <tr align="left" valign="top">
          <td class="bold2">attributes</td>
          <td>&#160;-&#160;</td>
          <td>
            <xsl:choose>
              <xsl:when test="attribute">
                <xsl:apply-templates select="attribute" mode="list"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>none</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </td>
        </tr><tr align="left" valign="top">
          <td class="bold2">methods</td>
          <td>&#160;-&#160;</td>
          <td>
            <xsl:choose>
              <xsl:when test="method">
                <xsl:apply-templates select="method" mode="list"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>none</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </td>
        </tr>
      </table>

      <xsl:if test="@inherits">
        <br />
        <div>
          <span class="bold2">Inherited properties: </span>
        </div>
        <table class="inner" border="0" cellspacing="0">
          <tr align="left" valign="top">
            <td class="bold2">attributes</td>
            <td>&#160;-&#160;</td>
            <td>
              <xsl:apply-templates select="key('interface',@inherits)/parent::*/attribute | key('interface',key('interface',@inherits)/parent::*/@inherits)/parent::*/attribute | key('interface',key('interface',key('interface',@inherits)/parent::*/@inherits)/parent::*/@inherits)/parent::*/attribute" mode="list">
                <xsl:with-param name="inherited">yes</xsl:with-param>
              </xsl:apply-templates>
            </td>
          </tr><tr align="left" valign="top">
            <td class="bold2">methods</td>
            <td>&#160;-&#160;</td>
            <td>
              <xsl:apply-templates select="key('interface',@inherits)/parent::*/method | key('interface',key('interface',@inherits)/parent::*/@inherits)/parent::*/method | key('interface',key('interface',key('interface',@inherits)/parent::*/@inherits)/parent::*/@inherits)/parent::*/method" mode="list">
                <xsl:with-param name="inherited">yes</xsl:with-param>
              </xsl:apply-templates>
            </td>
          </tr>
        </table>
      </xsl:if>

      <br />
      <div class="bold1">Description: </div>
      <div class="dataBody">
        <xsl:apply-templates select="description">
          <xsl:with-param name="module"><xsl:value-of select="$module"/></xsl:with-param>
        </xsl:apply-templates>
      </div>

      <br />
      <xsl:if test="note">
        <div class="bold1">Note: </div>
        <div class="dataBody">
          <xsl:apply-templates select="note">
            <xsl:with-param name="module"><xsl:value-of select="$module"/></xsl:with-param>
          </xsl:apply-templates>
        </div>
      </xsl:if>

      <!-- FOOTER -->
      <xsl:call-template name="footer"/>

    </body>
  </html>
</xsl:template>

<xsl:template match="attribute" mode="list">
  <xsl:param name="inherited">no</xsl:param>
  <xsl:variable name="whichClass"><xsl:value-of select="name()"/>Fg</xsl:variable>
  <a class="{$whichClass}" href="attribute_{@name}_{../@name}.html">
    <xsl:if test="$inherited = 'yes'">
      <xsl:attribute name="title">inherited from <xsl:value-of select="parent::interface/@name"/></xsl:attribute>
    </xsl:if>
    <xsl:value-of select="@name"/>
  </a>
  <xsl:if test="not(position()=last())">, </xsl:if>
</xsl:template>
<xsl:template match="method" mode="list">
  <xsl:param name="inherited">no</xsl:param>
  <xsl:variable name="whichClass"><xsl:value-of select="name()"/>Fg</xsl:variable>
  <a class="{$whichClass}" href="method_{@name}_{../@name}.html">
    <xsl:if test="$inherited = 'yes'">
      <xsl:attribute name="title">inherited from <xsl:value-of select="parent::interface/@name"/></xsl:attribute>
    </xsl:if>
    <xsl:value-of select="@name"/>
  </a>
  <xsl:if test="not(position()=last())">, </xsl:if>
</xsl:template>

</xsl:stylesheet>
